==> scale-0.2.1.tar.gz: scale-0.2.1/include/scale/graph.h <==
/*
 * $Id: graph.h,v 1.2 2004/07/09 09:43:58 jklein Exp $
 * $Author: jklein $
 * $Log: graph.h,v $
 * Revision 1.2  2004/07/09 09:43:58  jklein
 * few small changes.
 *
 * Revision 1.1  2004/06/24 15:16:50  jklein
 * sxarray_t was added for abstruction of collection structure.
 *
 */


/**
   This is not done.
   Do not try to compile this.
**/


#ifndef _SCALE_GRAPH_H_
#define _SCALE_GRAPH_H_

#include "scale/commons.h"
#include "scale/vector.h"
#include "scale/btree.h"


/** weight of graph-edge. */
typedef sint32 s_gweight_t; 

/** graph object */
typedef struct _sc_graph sgraph_t;

/** graph node */
typedef struct _sc_graph_node sgraph_node_t;

/** graph edge */
typedef struct sc_graph_edge sgraph_edge_t;


struct _sc_graph {
	size_t count;
	sc_compf_t compare;
	sbtree_t *nodes;
};


struct _sc_graph_node {
	suint32 key;
	spointer contents;
	svector_t *edges;
};


struct _sc_graph_edge {
	s_gweight_t weight;
	s_graph_node_t *tailnode;
};



sgraph_t *		s_graph_alloc(sc_compf_t cmpf);
void			s_graph_free(sgraph_t *g);
void			s_graph_add_node(sgraph_t *g, spointer node);
void			s_graph_add_edge(sgraph_t *g, spointer head,
								 spointer tail, s_gweight_t weight);
svector_t *		s_graph_get_nodes(sgraph_t *g);
svector_t *		s_graph_get_edges(sgraph_t *g, spoitner node);
svector_t *		s_graph_get_path(sgraph_t *g, spointer head, spointer tail);
sgraph_node_t *	s_graph_get_node(sgraph_t *g, spointer node);
sboolean		s_graph_node_exists(sgraph_t *g, spointer node);


#endif /* _SCALE_GRAPH_H_ */

==> scale-0.3.0.tar.gz: scale-0.3.0/include/scale/graph.h <==
/*
 * $Id: graph.h,v 1.3 2004/09/04 07:08:01 jklein Exp $
 * $Author: jklein $
 * $Log: graph.h,v $
 * Revision 1.3  2004/09/04 07:08:01  jklein
 * fixed "const spointer" to "sconstpointer".
 *
 * Revision 1.2  2004/07/09 09:43:58  jklein
 * few small changes.
 *
 * Revision 1.1  2004/06/24 15:16:50  jklein
 * sxarray_t was added for abstruction of collection structure.
 *
 */


/**
   This is not done.
   Do not try to compile this.
**/


#ifndef _SCALE_GRAPH_H_
#define _SCALE_GRAPH_H_

#include <scale/commons.h>
#include <scale/vector.h>
#include <scale/btree.h>


/** weight of graph-edge. */
typedef sint32 s_gweight_t; 

/** graph object */
typedef struct _sc_graph sgraph_t;

/** graph node */
typedef struct _sc_graph_node sgraph_node_t;

/** graph edge */
typedef struct sc_graph_edge sgraph_edge_t;


struct _sc_graph {
	size_t count;
	sc_compf_t compare;
	sbtree_t *nodes;
};


struct _sc_graph_node {
	suint32 key;
	spointer contents;
	svector_t *edges;
};


struct _sc_graph_edge {
	s_gweight_t weight;
	s_graph_node_t *tailnode;
};



sgraph_t *		s_graph_alloc(sc_compf_t cmpf);
void			s_graph_free(sgraph_t *g);
void			s_graph_add_node(sgraph_t *g, spointer node);
void			s_graph_add_edge(sgraph_t *g, spointer head,
								 spointer tail, s_gweight_t weight);
svector_t *		s_graph_get_nodes(sgraph_t *g);
svector_t *		s_graph_get_edges(sgraph_t *g, spoitner node);
svector_t *		s_graph_get_path(sgraph_t *g, spointer head, spointer tail);
sgraph_node_t *	s_graph_get_node(sgraph_t *g, spointer node);
sboolean		s_graph_node_exists(sgraph_t *g, spointer node);


#endif /* _SCALE_GRAPH_H_ */
